@@ -11,6 +11,7 @@ from .hexabundle import create_Magnet_Dictionary, get_probe_count, star_hexabund
 from ..problem_operations.robot_parameters import assign_magnet_labels, add_pickupDirection, \
                                                 assign_preferable_pickupDirection, calculate_pickup_putdown_angles, \
                                                 check_for_negative_twopi_angle, check_for_unresolvable_conflict
+from .fibres import convert_rectangularMagnetOrientation
 from ..hector.constants import robot_center_x,robot_center_y
 import numpy as np
 import string
@@ -48,8 +49,8 @@ def calculate_placement_ordering_of_all_blocked_magnets(list_of_fully_blocked_ma
         calculate_placement_ordering_of_blocked_magnet(blocked_magnet,list_of_conflicts,list_of_fully_blocked_magnets)
 
 # creating position ordering array which is one of the main outputs of the whole magnet collision code
-def create_position_ordering_array(all_magnets, fully_blocked_magnets, conflicted_magnets, galaxyIDrecord, \
-                                                                clusterNum, tileNum, conflictFile, flagsFile):
+def create_position_ordering_array(all_magnets, fully_blocked_magnets, conflicted_magnets, MagnetDict, galaxyIDrecord, \
+                                                                clusterNum, tileName, conflictFile):
 
     # calculating placement ordering of all the blocked magnets
     calculate_placement_ordering_of_all_blocked_magnets(fully_blocked_magnets, conflicted_magnets)
@@ -61,12 +62,12 @@ def create_position_ordering_array(all_magnets, fully_blocked_magnets, conflicte
     position_ordering_array = []
 
     # magnet label and guide hexabundle index
-    index1 = 1
-    guideIndex = 1
+    # index1 = 1
+    # guideIndex = 1
 
-    # carrying out the whole hexabundle allocation algorithm from hexabundles.py script
-    galaxyIDrecord, MagnetDict = overall_hexabundle_size_allocation_operation_version3_largerBundlePriority(all_magnets, \
-                                                                        galaxyIDrecord, clusterNum, tileNum, flagsFile)
+    # # carrying out the whole hexabundle allocation algorithm from hexabundles.py script
+    # galaxyIDrecord, MagnetDict = overall_hexabundle_size_allocation_operation_version3_largerBundlePriority(all_magnets, \
+    #                                                         galaxyIDrecord, mu_1re_cutoff, clusterNum, tileName, flagsFile)
 
     for magnet in all_magnets:
 
@@ -74,10 +75,10 @@ def create_position_ordering_array(all_magnets, fully_blocked_magnets, conflicte
         available_pickup = [area.code for area in magnet.pickup_areas]
 
         # checking for magnets with unresolvable conflicts, which are flagged and assigned order of '0'
-        order = check_for_unresolvable_conflict(magnet,conflictFile,max_order,clusterNum,tileNum)
+        order = check_for_unresolvable_conflict(magnet,conflictFile,max_order,clusterNum,tileName)
 
         # adding magnet labels of rectangular: R01.. ,and circular: Blu,Mag,Gre,Yel
-        magnet,index1 = assign_magnet_labels(magnet,index1)
+        # magnet,index1 = assign_magnet_labels(magnet,index1)
 
         # adding pickup direction to placement orders of 1 in the case of more than 1 placement orders
         magnet, available_pickup = add_pickupDirection(magnet, available_pickup)
@@ -85,8 +86,8 @@ def create_position_ordering_array(all_magnets, fully_blocked_magnets, conflicte
         # selecting only 1 pickup direction based on preference for circular: TR,TL,RO,RI and rectangular: I,O
         available_pickup = assign_preferable_pickupDirection(available_pickup)
 
-        # assigning allocated hexabundles to respective magnet as stored in Magnet Dictionary
-        magnet, guideIndex = hexabundle_allocation_fromMagnetDict (MagnetDict,magnet,guideIndex)
+        # # assigning allocated hexabundles to respective magnet as stored in Magnet Dictionary
+        # magnet, guideIndex = hexabundle_allocation_fromMagnetDict(MagnetDict,magnet,guideIndex)
 
         # calculating rotation angles for pickup and putdown based on available pickup direction
         magnet = calculate_pickup_putdown_angles(magnet,available_pickup)
@@ -96,14 +97,20 @@ def create_position_ordering_array(all_magnets, fully_blocked_magnets, conflicte
 
         ## ** Might need to change center coordinates of magnets to different scale for considering optical and other type of distortion **
 
+        # deriving probe_orientation column to be stored in positioning array for the fibres
+        probe_orientation = convert_rectangularMagnetOrientation(magnet)
+
         # storing all the parameters in positioning array
         f = np.append([magnet.__class__.__name__, str(magnet.magnet_label), str(robot_center_x+magnet.view_x), \
-                       str(robot_center_y+magnet.view_y), str(magnet.rotation_pickup), str(round(magnet.rotation_putdown,2)), \
-                       str(order), available_pickup, str(float(magnet.IDs)), str(int(magnet.index))], str(magnet.hexabundle))
+                       str(robot_center_y+magnet.view_y), str(magnet.rotation_pickup), str(magnet.rotation_putdown), \
+                       str(order), available_pickup, str(float(magnet.IDs)), str(int(magnet.index)), str(magnet.hexabundle), str(probe_orientation)], str(float(magnet.rectangular_magnet_input_orientation)))
 
         # appending each magnet with its established parameters to the position ordering array
         position_ordering_array.append(np.array(f))
 
+    # change numpy array data type from '<U19' to 'object' type
+    position_ordering_array = np.array(position_ordering_array, dtype=object)
+
+
     return np.array(position_ordering_array),galaxyIDrecord
 
-
